==> shopper_0.3.2.tar.gz: shopper-0.3.2/src/ui/ItemDialog.h <==
/* Shopper
 * Copyright (C) 2008 David Greaves
 *
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */
#include "shopperList.h"

namespace Shopper
{
// private base for adding/editing an Item
	class ItemDialog : public Gtk::Dialog
	{
//Tree model columns:
		class CatModel : public Gtk::TreeModel::ColumnRecord
		{
		public:
			CatModel();
			Gtk::TreeModelColumn<Shopper::Category*>     col_p;
			Gtk::TreeModelColumn<Glib::ustring> col_name;
		};
	public:
		int run();    // Calls Dialog run method and does add/edit
	protected:
		ItemDialog(Shopper::List*, Shopper::Item*);

		// accessor
		Shopper::Category*  get_category();
	
		// Data
		Shopper::List               *mylist;
		Shopper::Item               *myitem;

		// GUI
		Gtk::Entry                   desc_e;
		CatModel                     Columns;
		Gtk::ComboBox                Cat_combo;
		Glib::RefPtr<Gtk::ListStore> refTreeModel;

		//Helper
		int update_combo();   // returns the index of the active category
		// Button Callback
		void on_action_add_category();
	};
	class ItemEdit : public ItemDialog
	{
	public:
		ItemEdit(Shopper::List* mylist, Shopper::Item* it);
	};
	class ItemAdd : public ItemDialog
	{
	public:
		ItemAdd(Shopper::List* mylist);
	};

};

==> shopper_0.3.5.tar.gz: shopper-0.3.5/src/ui/ItemDialog.h <==
/* Shopper
 * Copyright (C) 2008 David Greaves
 *
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */
#include "shopperList.h"

namespace Shopper
{
// private base for adding/editing an Item
	class ItemDialog : public Gtk::Dialog
	{
//Tree model columns:
		class CatModel : public Gtk::TreeModel::ColumnRecord
		{
		public:
			CatModel();
			Gtk::TreeModelColumn<Shopper::Category*>     col_p;
			Gtk::TreeModelColumn<Glib::ustring> col_name;
		};
	public:
		int run();    // Calls Dialog run method and does add/edit
	protected:
		ItemDialog(Shopper::List*, Shopper::Item*);

		// accessor
		Shopper::Category*  get_category();
	
		// Data
		Shopper::List               *mylist;
		Shopper::Item               *myitem;

		// GUI
		Gtk::Entry                   desc_e;
		CatModel                     Columns;
		Gtk::ComboBox                Cat_combo;
		Glib::RefPtr<Gtk::ListStore> refTreeModel;

		//Helper
		int update_combo();   // returns the index of the active category
		// Button Callback
		void on_action_manage_category();
	};
	class ItemEdit : public ItemDialog
	{
	public:
		ItemEdit(Shopper::List* mylist, Shopper::Item* it);
	};
	class ItemAdd : public ItemDialog
	{
	public:
		ItemAdd(Shopper::List* mylist);
	};

};
